Opinions Response

|  | (Press Enter) - Sort forward/reverse by clicking on 'Date Filed' or 'Case' - Narrow results by searching for a keyword or number - For two or more results use'|' e.g. 'NEAL|ALPINE' - Refresh page to restore original results

Opinions — 2014

Date Filed | Case | Opinion
--- | --- | ---
02/26/2014 | Criminal No. 1981-0306 USA v. HINCKLEY | Doc No. 455 (order) Doc No. 456 (memorandum opinion and order) by Judge Paul L. Friedman
02/26/2014 | Civil Action No. 2013-1550 LOPES v. JETSETDC, LLC et al | Doc No. 36 (memorandum and opinion) Doc No. 38 (memorandum and opinion) by Judge Royce C. Lamberth
02/26/2014 | Civil Action No. 2013-0367 MALLORY v. UNITED STATES DEPARTMENT OF HOUSING AND URBAN DEVELOPMENT | Doc No. 11 (memorandum opinion) by Judge Colleen Kollar-Kotelly
02/26/2014 | Civil Action No. 2012-1249 MATTIACCIO v. DHA GROUP, INC. et al | Doc No. 84 (memorandum and opinion) Doc No. 86 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
02/26/2014 | Criminal No. 2011-0129 USA v. EDWARDS | Doc No. 864 (memorandum opinion) Doc No. 866 (memorandum opinion) by Judge Colleen Kollar-Kotelly
02/26/2014 | Civil Action No. 2009-2111 KOCH v. SCHAPIRO | Doc No. 40 (memorandum opinion and order) by Judge Paul L. Friedman
02/25/2014 | Civil Action No. 2014-0305 BROSTEN v. GEORGE WASHINGTON UNIVERSITY | Doc No. 3 (memorandum and opinion) by Judge Ellen S. Huvelle
02/25/2014 | Civil Action No. 2014-0304 ROWLAND v. UNITED STATES ATTORNEY'S OFFICE | Doc No. 3 (memorandum and opinion) by Judge Ellen S. Huvelle
02/25/2014 | Civil Action No. 2013-2002 DEMISSIE v. STARBUCKS CORPORATE OFFICE AND HEADQUARTERS | Doc No. 12 (memorandum order and opinion) by Judge Ellen S. Huvelle
02/25/2014 | Civil Action No. 2013-0749 GUMPAD et al v. COMMISSIONER OF SOCIAL SECURITY ADMINISTRATION | Doc No. 18 (memorandum opinion) by Judge Beryl A. Howell
02/25/2014 | Civil Action No. 2013-0025 ITPE PENSION FUND et al v. STRONGHOLD SECURITY, LLC | Doc No. 17 (order adopting report and recommendation) by Judge Amy Berman Jackson
02/25/2014 | Civil Action No. 2012-0264 HAWKINS v. POTOMAC LIGHTHOUSE PUBLIC CHARTER SCHOOL | Doc No. 36 (memorandum opinion) by Judge Gladys Kessler
02/25/2014 | Civil Action No. 2010-2021 FLYTHE v. DISTRICT OF COLUMBIA et al | Doc No. 86 (memorandum opinion & order) by Judge Rudolph Contreras
02/24/2014 | Civil Action No. 2012-1281 MARTIN v. U.S. EQUAL EMPLOYMENT OPPORTUNITY COMMISSION et al | Doc No. 52 (memorandum opinion) by Judge Ketanji Brown Jackson
02/24/2014 | Civil Action No. 2012-1245 STOUT v. NAPOLITANO | Doc No. 27 (memorandum opinion) by Judge Emmet G. Sullivan
02/24/2014 | Civil Action No. 2011-0456 LANDMARK HEALTH SOLUTIONS LLC v. NOT FOR PROFIT HOSPITAL CORPORATION | Doc No. 34 (memorandum opinion and order) by Judge Rudolph Contreras
02/24/2014 | Civil Action No. 2011-0391 UZOUKWU v. METROPOLITAN WASHINGTON COUNCIL OF GOVERNMENTS et al | Doc No. 69 (memorandum opinion and order) by Judge Robert L. Wilkins
02/21/2014 | Civil Action No. 2014-0283 SHAH v. HOLDER | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
02/21/2014 | Civil Action No. 2014-0282 ELWOOD v. OBAMA | Doc No. 3 (memorandum and opinion) by Judge Ellen S. Huvelle
02/21/2014 | Civil Action No. 2014-0280 WELLS v. HOLDER | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
02/21/2014 | Civil Action No. 2013-1936 JACKSON v. UNITED STATES PAROLE COMMISSION | Doc No. 11 (memorandum opinion) by Judge James E. Boasberg
02/21/2014 | Civil Action No. 2013-0447 FLETCHER v. U.S. DEPARTMENT OF JUSTICE | Doc No. 19 (memorandum opinion) by Judge Rudolph Contreras
02/21/2014 | Civil Action No. 2012-0335 HENOK v. CHASE HOME FINANCE, LLC et al | Doc No. 55 (memorandum opinion and order) by Judge Paul L. Friedman
02/21/2014 | Civil Action No. 2011-2220 BILAL-EDWARDS v. UNITED PLANNING ORGANIZATION et al | Doc No. 63 (memorandum opinion) by Judge Reggie B. Walton
02/21/2014 | Criminal No. 2008-0213 USA v. KOUMBAIRIA | Doc No. 304 (memorandum opinion) by Judge John D. Bates
02/21/2014 | Civil Action No. 2005-1276 BARKO v. HALLIBURTON COMPANY et al | Doc No. 145 (opinion and order) by Judge James S. Gwin
02/21/2014 | Civil Action No. 2004-1173 ESTATE OF ESTHER KLIEMAN et al v. PALESTINIAN AUTHORITY et al | Doc No. 238 (memorandum opinion and order) by Judge Paul L. Friedman
02/20/2014 | Civil Action No. 2012-1974 HIMEX COMPANY, INC. v. U.S. CUSTOMS AND BORDER PROTECTION | Doc No. 16 (memorandum and opinion) by Judge Richard J. Leon
02/20/2014 | Civil Action No. 2010-1424 LYLES v. DISTRICT OF COLUMBIA GOVERNMENT et al | Doc No. 53 (memorandum opinion) by Judge Rudolph Contreras
02/20/2014 | Civil Action No. 2009-1832 LEE v. GOVERNMENT OF THE DISTRICT OF COLUMBIA | Doc No. 95 (memorandum opinion) by Judge Rudolph Contreras
02/20/2014 | Civil Action No. 2005-0280 AL-ADAHI et al v. BUSH et al | Doc No. 643 (order) by Judge Gladys Kessler
02/19/2014 | Civil Action No. 2014-0256 JACKSON v. WELLS FARGO et al | Doc No. 4 (memorandum and opinion) by Judge Ellen S. Huvelle
02/19/2014 | Civil Action No. 2013-0252 DELTA SIGMA THETA SORORITY, INC. v. BIVINS et al | Doc No. 57 (memorandum opinion) by Judge Beryl A. Howell
02/19/2014 | Civil Action No. 2011-0660 FLAHERTY et al v. LOCKE et al | Doc No. 87 (memorandum opinion) by Judge Gladys Kessler
02/19/2014 | Civil Action No. 2006-1255 MARINO v. DRUG ENFORCEMENT ADMINISTRATION | Doc No. 95 (memorandum opinion) by Judge Gladys Kessler
02/19/2014 | Criminal No. 2004-0128 USA v. UNKNOWN | Doc No. 1239 (memorandum and opinion) by Judge Rosemary M. Collyer
02/18/2014 | Civil Action No. 1997-1629 BLACKMAN, et al v. DC, et al | Doc No. 2438 (memorandum opinion and order) by Judge Paul L. Friedman
02/18/2014 | Civil Action No. 2014-0245 STEWART v. UNITED STATES OF AMERICA | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
02/18/2014 | Civil Action No. 2014-0248 MATTHEWS v. PAUZE | Doc No. 4 (memorandum and opinion) by Judge Ellen S. Huvelle
02/18/2014 | Civil Action No. 2014-0233 NICKERSON v. UNITED STATES OF AMERICA et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
02/18/2014 | Civil Action No. 2014-0241 GASAWAY v. OFFICE OF DISPUTE RESOLUTION | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
02/18/2014 | Civil Action No. 2014-0249 WELLS v. GRAY | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
02/18/2014 | Civil Action No. 2014-0244 TAITE v. UNITED STATES PARDON ATTORNEY et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
02/18/2014 | Civil Action No. 2014-0239 FLORES v. GEORGE WASHINGTON UNIVERSITY | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
02/18/2014 | Civil Action No. 2014-0225 KEMPO v. UNITED STATES OF AMERICA | Doc No. 3 (memorandum and opinion) by Judge Ellen S. Huvelle
02/18/2014 | Civil Action No. 2013-0774 HARROD v. UNITED STATES PAROLE COMMISSION | Doc No. 16 (memorandum and opinion) by Judge Rosemary M. Collyer
02/18/2014 | Civil Action No. 2013-0770 OCEANA, INC. v. BLANK et al | Doc No. 37 (memorandum opinion) by Judge James E. Boasberg
02/18/2014 | Civil Action No. 2012-1389 AFRAM v. UNITED FOOD AND COMMERCIAL WORKERS UNIONS AND PARTICIPATING EMPLOYERS HEALTH AND WELFARE FUND, et al | Doc No. 33 (memorandum order) by Chief Judge Richard W. Roberts
02/18/2014 | Criminal No. 2011-0275 USA v. CARDOZA | Doc No. 60 (memorandum opinion and order) by Judge Amy Berman Jackson
02/18/2014 | Criminal No. 2008-0360 USA v. SLATTEN | Doc No. 388 (memorandum opinion) by Judge Royce C. Lamberth
02/18/2014 | Civil Action No. 2005-0280 AL-ADAHI et al v. BUSH et al | Doc No. 641 (order) by Judge Gladys Kessler
02/14/2014 | Civil Action No. 2013-0757 CIENFUEGOS v. OFFICE OF THE ARCHITECT OF THE CAPITOL | Doc No. 19 (amended memorandum opinion and order) by Judge James E. Boasberg
02/14/2014 | Civil Action No. 2013-0572 CONANT v. WELLS FARGO BANK, N.A. et al | Doc No. 45 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
02/14/2014 | Civil Action No. 2013-0288 DORSEN v. SECURITIES AND EXCHANGE COMMISSION | Doc No. 10 (memorandum opinion) by Judge Beryl A. Howell
02/14/2014 | Civil Action No. 2012-1036 SABA v. U.S. DEPARTMENT OF AGRICULTURE | Doc No. 29 (memorandum and opinion) by Judge Royce C. Lamberth
02/12/2014 | Civil Action No. 2012-2065 JACKSON et al v. TEAMSTERS LOCAL UNION 922 et al | Doc No. 54 (memorandum opinion) by Judge James E. Boasberg
02/12/2014 | Civil Action No. 2011-0701 MORRIS v. JACKSON | Doc No. 41 (memorandum and opinion) by Judge Rosemary M. Collyer
02/12/2014 | Civil Action No. 2011-0442 NATIONAL SECURITY COUNSELORS v. CENTRAL INTELLIGENCE AGENCY et al | Doc No. 67 (memorandum and opinion) by Judge Rosemary M. Collyer
02/12/2014 | Civil Action No. 2011-0123 AJISEFINNI v. KPMG LLP | Doc No. 56 (memorandum opinion) by Judge Rudolph Contreras
02/12/2014 | Civil Action No. 2004-1161 HOULAHAN v. WORLD WIDE ASSOCIATION OF SPECIALTY PROGRAMS AND SCHOOLS et al | Doc No. 178 (memorandum) by Judge Frederick J. Scullin, Jr
02/11/2014 | Civil Action No. 2013-1961 ELECTRONIC PRIVACY INFORMATION CENTER v. DEPARTMENT OF JUSTICE | Doc No. 15 (memorandum opinion) by Judge Ketanji Brown Jackson
02/11/2014 | Civil Action No. 2013-1392 LIEBMAN et al v. DEUTSCHE BANK NATIONAL TRUST COMPANY et al | Doc No. 45 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
02/11/2014 | Civil Action No. 2013-0757 CIENFUEGOS v. OFFICE OF THE ARCHITECT OF THE CAPITOL | Doc No. 18 (entered in error) by Judge James E. Boasberg
02/11/2014 | Civil Action No. 2011-1331 DANIELS v. DISTRICT OF COLUMBIA et al | Doc No. 41 (memorandum opinion) by Judge Beryl A. Howell
02/11/2014 | Criminal No. 2011-0059 USA v. NELSON | Doc No. 68 (memorandum opinion and order) by Chief Judge Richard W. Roberts
02/10/2014 | Civil Action No. 1998-2088 PURCELL, et al v. MWI CORPORATION, et al | Doc No. 472 (memorandum opinion) by Judge Gladys Kessler
02/10/2014 | Civil Action No. 2013-0315 INFORMATION STRATEGIES, INC. v. DUMOSCH | Doc No. 34 (memorandum opinion) by Judge Rudolph Contreras
02/10/2014 | Civil Action No. 2012-1177 DOAK v. NAPOLITANO | Doc No. 20 (memorandum opinion) by Judge Rudolph Contreras
02/10/2014 | Civil Action No. 2012-1123 K-N et al v. DISTRICT OF COLUMBIA | Doc No. 35 (order adopting amended report and recommendation) Doc No. 36 (memorandum and opinion) by Judge Amy Berman Jackson
02/10/2014 | Civil Action No. 2009-0394 BLAND-COLLINS v. HOWARD UNIVERSITY | Doc No. 100 (memorandum and opinion) by Judge Richard J. Leon
02/07/2014 | Civil Action No. 2013-0818 LOPEZ CASTRO et al v. FIDELITY AND DEPOSIT COMPANY OF MARYLAND et al | Doc No. 21 (memorandum opinion) by Judge James E. Boasberg
02/06/2014 | Civil Action No. 2013-1603 AYALA et al v. TITO CONTRACTORS, INC. et al | Doc No. 26 (memorandum opinion) by Judge James E. Boasberg
02/06/2014 | Civil Action No. 2013-0391 BANNEKER VENTURES LLC v. GRAHAM et al | Doc No. 39 (memorandum and opinion) by Judge Rosemary M. Collyer
02/06/2014 | Civil Action No. 2012-0625 SIMS v. DISTRICT OF COLUMBIA | Doc No. 32 (memorandum opinion) Doc No. 33 (order) by Judge Ellen S. Huvelle
02/05/2014 | Civil Action No. 2013-0873 ATKINSON v. GRINDSTONE CAPITAL LLC et al | Doc No. 21 (memorandum and opinion) by Judge Amy Berman Jackson
02/05/2014 | Civil Action No. 2013-0109 VALIDUS REINSURANCE, LTD. v. UNITED STATES OF AMERICA | Doc No. 29 (memorandum and opinion) by Judge Amy Berman Jackson
02/05/2014 | Civil Action No. 2012-0327 ELECTRONIC PRIVACY INFORMATION CENTER et al v. U.S. DEPARTMENT OF EDUCATION | Doc No. 31 (amended memorandum opinion) by Judge Amy Berman Jackson
02/04/2014 | Criminal No. 2013-0285 USA v. MURPHY | Doc No. 9 (memorandum opinion and order) by Judge Ketanji Brown Jackson
02/04/2014 | Civil Action No. 2013-0830 HALL AND ASSOCIATES v. UNITED STATES ENVIRONMENTAL PROTECTION AGENCY | Doc No. 21 (memorandum opinion) by Judge James E. Boasberg
02/04/2014 | Civil Action No. 2013-0675 RODRIGUEZ v. LABORATORY CORPORATION OF AMERICA HOLDINGS | Doc No. 21 (memorandum opinion) by Judge Gladys Kessler
02/04/2014 | Civil Action No. 2012-0696 BROWNE v. DONOVAN | Doc No. 40 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
02/03/2014 | Civil Action No. 2013-0573 MURPHY v. EXECUTIVE OFFICE FOR THE U.S. ATTORNEYS | Doc No. 32 (memorandum and opinion) by Judge Ellen S. Huvelle
02/03/2014 | Civil Action No. 2012-0833 JONES v. LISTENVISION STUDIOS et al | Doc No. 34 (memorandum opinion) by Judge Ketanji Brown Jackson
02/03/2014 | Civil Action No. 2012-0452 ROSENBERG v. UNITED STATES DEPARTMENT OF IMMIGRATION AND CUSTOMS ENFORCEMENT et al | Doc No. 80 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
02/03/2014 | Civil Action No. 2004-1166 BOUMEDIENE et al v. BUSH et al | Doc No. 323 (memorandum order) by Judge Richard J. Leon
01/31/2014 | Civil Action No. 2014-0162 GRENADIER v. HECKMAN et al | Doc No. 7 (memorandum and opinion) by Judge Reggie B. Walton
01/31/2014 | Civil Action No. 2013-1756 BRODT v. COUNTY OF HARFORD et al | Doc No. 4 (memorandum opinion) by Judge John D. Bates
01/31/2014 | Civil Action No. 2013-1416 TAYLOR v. VETERANS AFFAIRS ADMINISTRATION | Doc No. 34 (memorandum opinion) by Judge John D. Bates
01/31/2014 | Civil Action No. 2013-1055 TEFERA v. ONEWEST BANK, FSB | Doc No. 8 (memorandum opinion) by Judge Ketanji Brown Jackson
01/31/2014 | Civil Action No. 2013-0998 TEFERA v. WELLS FARGO BANK, N.A. | Doc No. 10 (memorandum opinion) by Judge Ketanji Brown Jackson
01/31/2014 | Civil Action No. 2013-0395 JAWORSKI v. UNITED STATES TREASURY | Doc No. 32 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/31/2014 | Civil Action No. 2013-0350 JARVIS et al., v. PARKER et al., | Doc No. 46 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/31/2014 | Civil Action No. 2012-0503 DELEON v. U.S. AIRWAYS, INC. et al | Doc No. 85 (memorandum opinion) by Judge Robert L. Wilkins
01/31/2014 | Civil Action No. 2010-1283 A.B. et al v. DISTRICT OF COLUMBIA et al | Doc No. 65 (order adopting in part report and recommendation) Doc No. 66 (memorandum and opinion) by Judge Amy Berman Jackson
01/31/2014 | Civil Action No. 2007-1718 PARR v. EBRAHIMIAN et al | Doc No. 125 (memorandum opinion and order) by Judge Paul L. Friedman
01/30/2014 | Civil Action No. 1997-1629 BLACKMAN, et al v. DC, et al | Doc No. 2424 (opinion) by Judge Paul L. Friedman
01/30/2014 | Civil Action No. 1993-0452 SALAZAR, et al v. DC, et al | Doc No. 1922 (amended memorandum opinion) by Judge Gladys Kessler
01/30/2014 | Civil Action No. 2014-0193 MORTON v. FULWOOD et al | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0137 BAMDAD v. DRUG ENFORCEMENT ADMINISTRATION et al | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0136 GLOVER v. URBINA et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0135 BELL-BOSTON v. UNITED STATES OF AMERICA et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0141 SMITH v. US DEPARTMENT OF JUSTICE et al | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0134 WOODS v. UNITED STATES DEPARTMENT OF JUSTICE | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0131 SMITH v. HOLDER et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0142 JARVIS v. DISTRICT OF COLUMBIA et al | Doc No. 4 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0145 DUNLAP v. DEPARTMENT REVIEW BOARD APPEAL BRANCH et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0144 HILL v. W.H.H. TRICE AND COMPANY | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0147 WRIGHT v. U.S. LABOR WORKFORCE/NATIONAL SECURITY | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0138 ROWLAND v. UNITED STATES SUPERIOR COURT | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2014-0140 BROWN v. HILL et al | Doc No. 3 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2013-1665 HAMES v. UNITED STATES OF AMERICA | Doc No. 5 (memorandum and opinion) by Judge Reggie B. Walton
01/30/2014 | Civil Action No. 2013-1418 MCCAIN v. BANK OF AMERICA, NA et al | Doc No. 33 (memorandum opinion) by Judge Beryl A. Howell
01/30/2014 | Civil Action No. 2013-1008 DISTRICT OF COLUMBIA v. MASUCCI et al | Doc No. 28 (order) Doc No. 29 (opinion) Doc No. 30 (memorandum opinion and order) by Judge Paul L. Friedman
01/30/2014 | Civil Action No. 2013-0696 DUFFY v. BANK OF AMERICA, N.A., et al | Doc No. 24 (memorandum opinion) by Judge Gladys Kessler
01/30/2014 | Civil Action No. 2011-0806 SABRE INTERNATIONAL SECURITY v. TORRES ADVANCED ENTERPRISE SOLUTIONS, LLC | Doc No. 288 (memorandum opinion) by Judge Gladys Kessler
01/29/2014 | Civil Action No. 2013-1297 ROBINSON v. DISTRICT OF COLUMBIA | Doc No. 20 (memorandum opinion) by Judge Ellen S. Huvelle
01/29/2014 | Civil Action No. 2013-0294 ESTATE OF ANDRE P. RUDDER v. VILSACK | Doc No. 14 (memorandum and opinion) by Judge Richard J. Leon
01/29/2014 | Civil Action No. 2012-1617 COMPETITIVE ENTERPRISE INSTITUTE v. UNITED STATES ENVIRONMENTAL PROTECTION AGENCY | Doc No. 42 (memorandum opinion) by Judge James E. Boasberg
01/29/2014 | Civil Action No. 2011-0544 REILLY v. USA | Doc No. 14 (memorandum opinion) by Judge Ketanji Brown Jackson
01/28/2014 | Civil Action No. 1993-0452 SALAZAR, et al v. DC, et al | Doc No. 1919 (memorandum opinion) by Judge Gladys Kessler
01/28/2014 | Civil Action No. 2013-0343 SCHWARTZ PARTNERS PACKAGING, LLC v. NATIONAL LABOR RELATIONS BOARD et al | Doc No. 21 (memorandum opinion) by Judge Beryl A. Howell
01/28/2014 | Civil Action No. 2012-1170 BROWN v. HARTFORD LIFE AND ACCIDENT INSURANCE COMPANY | Doc No. 35 (memorandum and opinion) by Judge Richard J. Leon
01/28/2014 | Civil Action No. 2011-1362 YOUSSEF v. FEDERAL BUREAU OF INVESTIGATION et al | Doc No. 53 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/28/2014 | Criminal No. 2008-0126 USA v. DESTINE | Doc No. 56 (memorandum opinion) by Judge Colleen Kollar-Kotelly
01/27/2014 | Civil Action No. 2013-1536 BLACKWELL v. SECTEK, INC. | Doc No. 10 (order) by Judge John D. Bates
01/27/2014 | Civil Action No. 2013-0108 CLEMENTE v. FEDERAL BUREAU OF INVESTIGATION, et al | Doc No. 18 (memorandum opinion) by Judge Thomas F. Hogan
01/27/2014 | Civil Action No. 2012-1274 SIMBAQUEBA v. UNITED STATES SECRET SERVICE et al | Doc No. 34 (memorandum and opinion) by Judge John D. Bates
01/27/2014 | Civil Action No. 2010-0652 BESHIR v. HOLDER et al | Doc No. 41 (memorandum opinion) by Judge John D. Bates
01/24/2014 | Civil Action No. 2014-0181 YAKOVETSv. BAILIN et al | Doc No. 27 (memorandum) by Judge James K. Bredar
01/24/2014 | Civil Action No. 2013-0098 WARD v. DISTRICT OF COLUMBIA | Doc No. 23 (opinion adopting r) by Judge Ketanji Brown Jackson
01/24/2014 | Civil Action No. 2012-0605 SPERLING v. OFFICE OF INFORMATION POLICY et al | Doc No. 26 (memorandum opinion) by Judge Ketanji Brown Jackson
01/24/2014 | Civil Action No. 2012-0147 ROBINSON v. ERGO SOLUTIONS, LLC | Doc No. 23 (memorandum opinion) by Judge John D. Bates
01/23/2014 | Civil Action No. 2013-1525 WOODS v. KURLAND et al | Doc No. 6 (memorandum opinion) by Judge Ellen S. Huvelle
01/23/2014 | Civil Action No. 2013-0084 LEGGETT et al v. DISTRICT OF COLUMBIA | Doc No. 17 (memorandum opinion) by Judge Reggie B. Walton
01/23/2014 | Civil Action No. 2012-0248 MCNAIR v. GOVERNMENT OF THE DISTRICT OF COLUMBIA | Doc No. 37 (memorandum opinion) by Judge James E. Boasberg
01/23/2014 | Civil Action No. 2012-0228 GUERRERO-SMITH v. SOLIS | Doc No. 21 (memorandum and opinion) by Judge Barbara Jacobs Rothstein
01/23/2014 | Civil Action No. 2011-1645 KOCH v. HOLDER | Doc No. 25 (memorandum opinion and order) by Judge Paul L. Friedman
01/22/2014 | Civil Action No. 2013-0535 FBR CAPITAL MARKETS AND COMPANY v. HANS | Doc No. 20 (memorandum and opinion) by Judge Royce C. Lamberth
01/22/2014 | Civil Action No. 2012-0843 BLOOMGARDEN v. UNITED STATES DEPARTMENT OF JUSTICE | Doc No. 31 (memorandum opinion) by Judge Ellen S. Huvelle
01/22/2014 | Civil Action No. 2012-0111 AMERICAN FOREST RESOURCE COUNCIL et al v. ASHE et al | Doc No. 76 (memorandum opinion) by Judge John D. Bates
01/22/2014 | Civil Action No. 2008-1309 KNOWLAND v. GREAT SOCIALIST PEOPLE'S LIBYAN ARAB JAMAHIRIYA et al | Doc No. 34 (memorandum and opinion) by Judge Rosemary M. Collyer
01/21/2014 | Misc. No. 2014-0128 CAMARDA, et al v. CERTIFIED FINANCIAL PLANNER BOARD OF STANDARDS, INC | Doc No. 7 (order) by Judge Richard J. Leon
01/21/2014 | Civil Action No. 2012-0917 REYNOLDS v. U.S. DEPARTMENT OF JUSTICE et al | Doc No. 46 (memorandum and opinion) by Judge Royce C. Lamberth
01/21/2014 | Civil Action No. 2011-0391 UZOUKWU v. METROPOLITAN WASHINGTON COUNCIL OF GOVERNMENTS et al | Doc No. 60 (memorandum and opinion) by Judge Robert L. Wilkins
01/17/2014 | Civil Action No. 2013-1518 SERVICE EMPLOYEES INTERNATIONAL UNION NATIONAL INDUSTRY PENSION FUND et al v. D&M PROPERTY MAINTENANCE, INC. | Doc No. 10 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/17/2014 | Civil Action No. 2013-0608 AARP v. SYCLE | Doc No. 16 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/17/2014 | Civil Action No. 2013-0390 ZEVALLOS v. OBAMA et al | Doc No. 20 (memorandum opinion) by Judge Rudolph Contreras
01/17/2014 | Civil Action No. 2010-1100 AWAN v. UNITED STATES DEPARTMENT OF JUSTICE et al | Doc No. 72 (memorandum opinion) by Judge Beryl A. Howell
01/17/2014 | Civil Action No. 2007-1757 In Re: HARMAN INTERNATIONAL INDUSTRIES, INC. SECURITIES LITIGATION | Doc No. 57 (memorandum opinion) by Judge Rudolph Contreras
01/16/2014 | Civil Action No. 2013-0359 THOMAS v. NAPOLITANO et al | Doc No. 31 (memorandum and opinion) by Judge Gladys Kessler
01/16/2014 | Civil Action No. 2012-1527 DISTRICT OF COLUMBIA v. WOLFIRE | Doc No. 25 (order) Doc No. 26 (memorandum and opinion) by Judge Amy Berman Jackson
01/16/2014 | Civil Action No. 2012-0045 TURNER v. UNITED STATES CAPITOL POLICE BOARD | Doc No. 23 (memorandum opinion and order) by Judge Rudolph Contreras
01/15/2014 | Civil Action No. 2013-0623 HALBIG et al v. SEBELIUS et al | Doc No. 66 (order) Doc No. 67 (opinion) by Judge Paul L. Friedman
01/14/2014 | Civil Action No. 2012-1352 COLEMAN v. NAPOLITANO | Doc No. 18 (opinion) by Judge Paul L. Friedman
01/13/2014 | Civil Action No. 2013-1967 ADAMS v. DEPARTMENT OF TREASURY et al | Doc No. 3 (memorandum and opinion) by Judge Richard J. Leon
01/13/2014 | Civil Action No. 2013-1526 SHAW v. ONE WEST BANK, FSB et al | Doc No. 23 (memorandum opinion and order) by Judge Robert L. Wilkins
01/13/2014 | Civil Action No. 2013-0917 BAILEY v. CITIMORTGAGE, INC. | Doc No. 11 (memorandum opinion) by Judge Richard J. Leon
01/13/2014 | Civil Action No. 2013-0529 FLORIDA BANKERS ASSOCIATION, et al v. UNITED STATES DEPARTMENT OF TREASURY et al | Doc No. 28 (memorandum opinion) by Judge James E. Boasberg
01/13/2014 | Civil Action No. 2012-2046 WALKER et al v. INNOVATIVE CONCEPT SOLUTIONS INTERNATIONAL, INC. et al | Doc No. 24 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/13/2014 | Criminal No. 2012-0055 USA v. SMALL | Doc No. 32 (memorandum opinion and order) by Chief Judge Richard W. Roberts
01/13/2014 | Criminal No. 2009-0135 USA v. ARMSTRONG | Doc No. 53 (memorandum order) by Chief Judge Richard W. Roberts
01/10/2014 | Civil Action No. 2013-1885 BIMINI SUPERFAST OPERATIONS LLC et al v. WINKOWSKI et al | Doc No. 35 (memorandum and opinion) Doc No. 37 (memorandum and opinion) by Judge Colleen Kollar-Kotelly
01/10/2014 | Civil Action No. 2013-1527 HAM v. METROPOLITAN POLICE DEPARTMENT et al | Doc No. 11 (memorandum opinion) by Judge Ellen S. Huvelle
01/10/2014 | Civil Action No. 2013-1349 DAVIS v UNITED STATES OF AMERICA | Doc No. 12 (memorandum opinion) Doc No. 13 (order) by Judge Ellen S. Huvelle
01/10/2014 | Civil Action No. 2013-1218 WASHINGTON v. COASTAL INTERNATIONAL SECURITY et al | Doc No. 11 (memorandum and opinion) by Judge John D. Bates
01/10/2014 | Civil Action No. 2013-0794 GALINDO v. UNITED STATES OF AMERICA | Doc No. 13 (memorandum and opinion) by Judge Emmet G. Sullivan
01/10/2014 | Civil Action No. 2012-1025 MARCUSSE v. UNITED STATES DEPARTMENT OF JUSTICE OFFICE OF INFORMATION POLICY et al | Doc No. 47 (memorandum opinion) by Judge Colleen Kollar-Kotelly
01/09/2014 | Civil Action No. 2013-1398 PITTS v. HOWARD UNIVERSITY | Doc No. 10 (memorandum opinion) by Judge James E. Boasberg
01/08/2014 | Civil Action No. 2012-1291 FOUCH v. DISTRICT OF COLUMBIA et al | Doc No. 25 (memorandum and opinion) by Judge Emmet G. Sullivan
01/08/2014 | Civil Action No. 2011-0730 ABRAXIS BIOSCIENCE, LLC v. KAPPOS | Doc No. 32 (memorandum opinion) by Judge Beryl A. Howell
01/07/2014 | Civil Action No. 2011-1601 SPADONE v. MCHUGH | Doc No. 43 (memorandum opinion) by Judge Barbara Jacobs Rothstein
01/07/2014 | Civil Action No. 2010-0487 HANCOCK v. WASHINGTON HOSPITAL CENTER | Doc No. 89 (memorandum opinion and order) by Judge Robert L. Wilkins
01/06/2014 | Civil Action No. 2013-0698 RENCHARD v. PRINCE WILLIAM MARINE SALES, INC. et al | Doc No. 18 (memorandum opinion) by Judge Beryl A. Howell
01/06/2014 | Civil Action No. 2012-0259 UNITED STATES OF AMERICA v. FUNDS UP TO AND INCLUDING THE AMOUNT OF $56,634 IN U.S. CURRENCY et al | Doc No. 39 (memorandum and opinion) by Judge Amy Berman Jackson
01/06/2014 | Civil Action No. 2012-0133 CANNON et al v. DISTRICT OF COLUMBIA | Doc No. 57 (memorandum opinion) by Judge Ellen S. Huvelle
01/06/2014 | Civil Action No. 2011-0116 DISTRICT HOSPITAL PARTNERS, L.P. et al v. SEBELIUS | Doc No. 124 (memorandum opinion) by Judge Ellen S. Huvelle
01/03/2014 | Civil Action No. 2014-0021 SHIPMAN v. LOGISTICS HEALTH, INC. | Doc No. 4 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2014-0027 JACKSON v. SUTER et al | Doc No. 5 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2014-0026 HILLIARD v. AMTRAK et al | Doc No. 6 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2014-0025 GRUMBLEY v. HIGGINS | Doc No. 4 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2014-0023 BROWN v. HOLDER et al | Doc No. 3 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2014-0022 JONES v. UNITED STATES OF AMERICA | Doc No. 4 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2014-0009 BRESTLE v. SAMUELS | Doc No. 3 (memorandum and opinion) by Judge Emmet G. Sullivan
01/03/2014 | Civil Action No. 2005-1437 DL et al v. DISTRICT OF COLUMBIA et al | Doc No. 404 (memorandum and opinion) by Judge Royce C. Lamberth
01/02/2014 | Civil Action No. 2013-1941 MALIBU MEDIA, LLC v. DOE | Doc No. 8-2 (memorandum order) by Magistrate Judge John M. Facciola
01/02/2014 | Civil Action No. 2013-1515 COLEY v. UNITED STATES PAROLE COMMISSION et al | Doc No. 10 (memorandum opinion) by Judge Amy Berman Jackson
01/02/2014 | Civil Action No. 2013-0560 HINES v. DISTRICT OF COLUMBIA | Doc No. 23 (memorandum opinion) by Judge James E. Boasberg
01/02/2014 | Civil Action No. 2010-0976 LANDIS v. TAILWIND SPORTS CORPORATION et al | Doc No. 145 (memorandum opinion and order) by Judge Robert L. Wilkins
01/02/2014 | Civil Action No. 2006-2125 FRIEDMAN v. U.S. SECRET SERVICE | Doc No. 101 (memorandum and opinion) by Judge Ketanji Brown Jackson